pub struct DeviceInfo { /* private fields */ }Expand description
Description of the media device.
Implementations
Sourceimpl DeviceInfo
impl DeviceInfo
Sourcepub fn driver(&self) -> &str
pub fn driver(&self) -> &str
Name of the driver implementing the media API as an ASCII string. The driver version is stored in the driver_version field.
Driver specific applications can use this information to verify the driver identity. It is also useful to work around known bugs, or to identify drivers in error reports.
Sourcepub fn model(&self) -> &str
pub fn model(&self) -> &str
Device model name as an UTF-8 string. The device version is stored in the device_version field and is not be appended to the model name.
Sourcepub fn bus_info(&self) -> &str
pub fn bus_info(&self) -> &str
Location of the device in the system as an ASCII string. This includes the bus type name (PCI, USB, …) and a bus-specific identifier.
Sourcepub fn media_version(&self) -> String
pub fn media_version(&self) -> String
Media API version, already formatted as a kernel version.
Sourcepub fn hw_revision(&self) -> u32
pub fn hw_revision(&self) -> u32
Hardware device revision in a driver-specific format.
Sourcepub fn driver_version(&self) -> String
pub fn driver_version(&self) -> String
Media device driver version, already formatted as a kernel version. Together with the driver field this identifies a particular driver.